Documentation
¶
Index ¶
Constants ¶
const StackSize = 2048
StackSize is the maximum size the stack can take
Variables ¶
var False = &object.Boolean{Value: false}
False - an invariant false object
var True = &object.Boolean{Value: true}
True - an invariant true object
Functions ¶
This section is empty.
Types ¶
type VM ¶
type VM struct {
// contains filtered or unexported fields
}
VM represents the virtual machine
func (*VM) LastPopped ¶
LastPopped returns the item just popped from the stack
Click to show internal directories.
Click to hide internal directories.